@@ -254,11 +254,11 @@ class MainFrameRes(QtGui.QWidget):
                                                     (sid, view_params)
             except sudsds.MethodNotFound:
                 return
-            if self._parent.ClientObj.method_names.has_key(self.method_name):
-                view_method = self._parent.ClientObj.method_names \
-                                                        [self.method_name]
-            else:
-                view_method = self.method_name
+            #if self._parent.ClientObj.method_names.has_key(self.method_name):
+            #    view_method = self._parent.ClientObj.method_names \
+            #                                            [self.method_name]
+            #else:
+            view_method = self.method_name
             self._parent.ClientObj._parent.setWindowTitle(view_method + \
                         ' - ' + self.ClientObj.Name)
             self._parent.main_frame_view(view, view_method, \
@@ -426,7 +426,6 @@ class MainFrameRes(QtGui.QWidget):
     #    for mess in meth_result:
             self.ClientObj.app.processEvents()
             mess = meth_result
-            print mess.type
             if mess.type == 'pid':
                 self.get_messages(self.ClientObj.sid, mess.message)
             if mess.type == 'error':
