@@ -22,13 +22,7 @@ from calculate.core.client.function import switch
 
 from more import get_sid, ClientServiceThread, show_msg, ErrorWgt, ResultLayout
 from more import LabelWordWrap as Label
-
-class LabelWordWrap(Label):
-    def __init__(self, name, parent = None):
-        Label.__init__(self, name, parent)
-        # set text selectable
-        self.setTextInteractionFlags(self.textInteractionFlags() | \
-                                     QtCore.Qt.TextSelectableByMouse)
+from MainFrameResult import LabelWordWrap,ChoiceDialog
 
 class TaskWidget(QtGui.QWidget):
     def __init__(self, taskNumber = 1, parent = None):
@@ -143,15 +137,16 @@ class ShortFrameRes(QtGui.QWidget):
     def show_view(self, view):
         pass
 
-    def show_normal(self, message):
+    def show_normal(self, message, mono=False):
         # add normal message label
-        if hasattr (self, 'taskWidget'):
+        if hasattr (self, 'taskWidget') and not mono:
             self.taskWidget.setText(message)
         else:
             if message:
                 # add normal message label
-                lbl_temp = LabelWordWrap(message, self)
+                lbl_temp = LabelWordWrap(message, self, mono=mono)
                 lbl_temp.setMinimumHeight(lbl_temp.sizeHint().height())
+                lbl_temp.setMaximumHeight(lbl_temp.sizeHint().height())
                 self.work_layout._addWidget(lbl_temp)
                 self.initUI()
 
@@ -162,6 +157,7 @@ class ShortFrameRes(QtGui.QWidget):
         lbl_temp = ErrorWgt(message, self)
         lbl_temp.set_error()
         lbl_temp.setMinimumHeight(lbl_temp.sizeHint().height())
+        lbl_temp.setMaximumHeight(lbl_temp.sizeHint().height())
         self.work_layout._addWidget(lbl_temp)
         if hasattr (self, 'taskWidget'):
             self.taskWidget.set_error()
@@ -171,6 +167,8 @@ class ShortFrameRes(QtGui.QWidget):
         # add warning message label
         lbl_temp = ErrorWgt(item.message, self)
         lbl_temp.set_warning()
+        lbl_temp.setMinimumHeight(lbl_temp.sizeHint().height())
+        lbl_temp.setMaximumHeight(lbl_temp.sizeHint().height())
         self.work_layout._addWidget(lbl_temp)
         self.initUI()
 
@@ -295,10 +293,18 @@ class ShortFrameRes(QtGui.QWidget):
         except:
             return 1
         """ get one message by its type """
+        if not hasattr(item,"type"):
+            return 1
         for case in switch(item.type):
             if case('normal'):
                  self.show_normal(item.message)
                  return 1
+            if case('plain'):
+                 self.show_normal(item.message)
+                 return 1
+            if case('pre'):
+                 self.show_normal(item.message,mono=True)
+                 return 1
             if case('progress'):
                  self.get_Progress(sid, pid, item.id)
                  return 1
@@ -320,6 +326,12 @@ class ShortFrameRes(QtGui.QWidget):
             if case('question'):
                 self.send_Message(sid, pid, item)
                 return 1
+            if case('confirm'):
+                self.send_Confirm(sid, pid, item)
+                return 1
+            if case('choice'):
+                self.send_Choice(sid, pid, item)
+                return 1
             if case('password'):
                 self.send_Password(sid, pid, item)
                 return 1
@@ -536,6 +548,16 @@ class ShortFrameRes(QtGui.QWidget):
             self.ClientObj.app.processEvents()
             self.initUI()
 
+    def send_Confirm(self, sid, pid, item):
+        """ send answer to the question """
+        self.message = ConfirmDialog(self, item, sid, pid)
+        self.message.show()
+
+    def send_Choice(self, sid, pid, item):
+        """ send answer to the question """
+        self.message = ChoiceDialog(self, item, sid, pid)
+        self.message.show()
+
     def send_Message(self, sid, pid, item):
         """ send answer to the question """
         self.message = MessageDialog(self, item, sid, pid)
@@ -567,6 +589,10 @@ class ShortFrameRes(QtGui.QWidget):
         self.close_all_thread()
         self._parent.methodname_wgt._hide()
         self._parent.control_button._hide()
+        if hasattr(self,"message") and self.message:
+            self.message.close()
+        if hasattr(self,"passwd") and self.passwd:
+            self.passwd.close()
         event.accept()
             
 class MessageDialog(QtGui.QWidget):
@@ -643,3 +669,63 @@ class MessageDialog(QtGui.QWidget):
             self.send_button.setDisabled(True)
         else:
             self.send_button.setEnabled(True)
+
+class ConfirmDialog(QtGui.QWidget):
+    # answer to the server question
+    def __init__(self, parent, item, sid, pid):
+        super(ConfirmDialog, self).__init__()
+        self._parent = parent
+#        self.item = item
+        self.sid = sid
+        self.pid = pid
+        self.layout = QtGui.QGridLayout(self)
+
+        self.label = LabelWordWrap(item.message, self)
+
+        self.layout.addWidget(self.label,0,0,1,2)
+
+        self.yes_button = QtGui.QPushButton(_('Yes'), self)
+        self.yes_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
+        self.yes_button.clicked.connect(self.sendYes)
+        
+        self.layout.addWidget(self.yes_button,1,0)
+
+        self.no_button = QtGui.QPushButton(_('No'), self)
+        self.no_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Escape))
+        self.no_button.clicked.connect(self.sendNo)
+        
+        self.layout.addWidget(self.no_button,1,1)
+                          
+        self.move(parent.ClientObj._parent.geometry().x() + \
+                  parent.ClientObj._parent.geometry().width() / 2 \
+                  - self.sizeHint().width() / 2, \
+                  parent.ClientObj._parent.geometry().y() + \
+                  parent.ClientObj._parent.geometry().height() / 2 \
+                  - self.sizeHint().height() / 2)
+        self.setWindowFlags (QtCore.Qt.WindowMinimizeButtonHint)
+#        self.setAttribute(QtCore.Qt.WA_ShowModal)
+        
+    def send(self,answer):
+        # Call server method
+        if hasattr (self, 'send_password_thread'):
+            if self.send_password_thread.isRunning():
+                return 1
+        self.send_password_thread = ClientServiceThread(\
+                        self._parent.ClientObj, 'send_message', self.sid, \
+                        self.pid, answer, return_except = True)
+        self.send_password_thread.signal.connect(self.send_after)
+        self.send_password_thread.start()            
+
+    def sendYes(self):
+        self.send("yes")
+
+    def sendNo(self):
+        self.send("no")
+
+    def send_after(self, result):
+        if type(result) == Exception:
+            show_msg(_('Failed to send the message (password) to the server'))
+            self.close()
+            return 1
+        self._parent.show_result(result)
+        self.close()
